from .pyDRMetrics import *
import sys
import json
import uuid 
import os

# Three params passed from C#
if __name__ == "__main__":
    csvX = sys.argv[1]
    csvZ = sys.argv[2]
    csvXr = sys.argv[3]

    drm = DRMetrics.from_files(csvX, csvZ, csvXr)

    fn = os.path.dirname(os.path.realpath(__file__)) + "/" + str(uuid.uuid4()) + ".html"
    with open(fn, 'w') as f:
        f.write(drm.get_html())

    #print(os.getcwd())
    print(fn)
    #print(json.dumps(d))
    


#
# Sample Reconstruction Visualization: Compare orginal and reconstructed samples side by side

from matplotlib import pyplot as plt
from .plt2base64 import *

def visualize_sample_reconstruction(X, Xr, X_names, N = 3, silent = False):
    
    assert X.shape == Xr.shape
    assert X.shape[1] == len(X_names)

    # number of test samples
    N = min(N, X.shape[0])
    
    plt.figure(figsize=(18, 2*N)) # 100, 12*N

    if (silent == False):
        print("left column: original waveform\t\t right column: recovered waveform")

    for i in range(N):
        # original
        ax = plt.subplot(N, 2, i*2 + 1)
        plt.scatter(X_names, list(X[i]), s = 1)        
        ax.get_xaxis().set_visible(False)
        ax.get_yaxis().set_visible(False)

        # reconstruction
        ax = plt.subplot(N, 2, i*2 + 2)
        plt.scatter(X_names, list(Xr[i]), s = 1)
        ax.get_xaxis().set_visible(False)
        ax.get_yaxis().set_visible(False)

    plt.tight_layout()
    s = plt2html(plt)

    if (silent == False):
        plt.show()

    return s


import matplotlib.pyplot as plt
from .plt2base64 import *

def visualize_matrix(dm, cmap = None, silent = False):

    fig = plt.figure(figsize = (3,3))
    if cmap is None:
        plt.imshow(dm)
    else:
        plt.imshow(dm, cmap = cmap)

    cur_axes = plt.gca()
    cur_axes.axes.get_xaxis().set_visible(False)
    cur_axes.axes.get_yaxis().set_visible(False) 

    fig.tight_layout()
        
    s = plt2html(plt) # must appear before plt.show()

    if (silent == False):
        plt.show()
    return s